A range of bytes to fetch.
Each Range::Bytes header can contain one or more ByteRangeSpecs.
Variants
FromTo(u64, u64)
All bytes from x to y, inclusive.
Serialized as x-y.
Example: bytes=500-999 would represent the second 500 bytes.
From(u64)
All bytes starting from x, inclusive.
Serialized as x-.
Example: For a file of 1000 bytes, bytes=950- would represent bytes 950-999, inclusive.
Last(u64)
The last y bytes, inclusive.
Using the spec terminology, this is suffix-byte-range-spec. Serialized as -y.
Example: For a file of 1000 bytes, bytes=-50 is equivalent to bytes=950-.
Implementations
sourceimpl ByteRangeSpec
impl ByteRangeSpec
sourcepub fn to_satisfiable_range(&self, full_length: u64) -> Option<(u64, u64)>
pub fn to_satisfiable_range(&self, full_length: u64) -> Option<(u64, u64)>
Given the full length of the entity, attempt to normalize the byte range into an satisfiable
end-inclusive (from, to) range.
The resulting range is guaranteed to be a satisfiable range within the bounds
of 0 <= from <= to < full_length.
If the byte range is deemed unsatisfiable, None is returned. An unsatisfiable range is
generally cause for a server to either reject the client request with a
416 Range Not Satisfiable status code, or to simply ignore the range header and serve the
full entity using a 200 OK status code.
This function closely follows RFC 7233 2.1. As such, it considers ranges to be satisfiable if they meet the following conditions:
If a valid byte-range-set includes at least one byte-range-spec with a first-byte-pos that is less than the current length of the representation, or at least one suffix-byte-range-spec with a non-zero suffix-length, then the byte-range-set is satisfiable. Otherwise, the byte-range-set is unsatisfiable.
The function also computes remainder ranges based on the RFC:
If the last-byte-pos value is absent, or if the value is greater than or equal to the current length of the representation data, the byte range is interpreted as the remainder of the representation (i.e., the server replaces the value of last-byte-pos with a value that is one less than the current length of the selected representation).