pub struct Expires(pub HttpDate);Expand description
Expires header, defined
in RFC 7234 5.3
The Expires header field gives the date/time after which the
response is considered stale.
The presence of an Expires field does not imply that the original resource will change or cease to exist at, before, or after that time.
ABNF
Expires = HTTP-date
Example Values
Thu, 01 Dec 1994 16:00:00 GMT
Examples
use std::time::{SystemTime, Duration};
use actix_web::HttpResponse;
use actix_web::http::header::Expires;
let mut builder = HttpResponse::Ok();
let expiration = SystemTime::now() + Duration::from_secs(60 * 60 * 24);
builder.insert_header(
Expires(expiration.into())
);Tuple Fields
0: HttpDateTrait Implementations
sourceimpl Header for Expires
impl Header for Expires
sourcefn name() -> HeaderName
fn name() -> HeaderName
Returns the name of the header field.
sourcefn parse<M: HttpMessage>(msg: &M) -> Result<Self, ParseError>
fn parse<M: HttpMessage>(msg: &M) -> Result<Self, ParseError>
Parse the header from a HTTP message.
sourceimpl TryIntoHeaderValue for Expires
impl TryIntoHeaderValue for Expires
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
The type returned in the event of a conversion error.
sourcefn try_into_value(self) -> Result<HeaderValue, Self::Error>
fn try_into_value(self) -> Result<HeaderValue, Self::Error>
Try to convert value to a HeaderValue.
impl Eq for Expires
impl StructuralEq for Expires
impl StructuralPartialEq for Expires