pub struct IfModifiedSince(pub HttpDate);Expand description
If-Modified-Since header, defined
in RFC 7232 3.3
The If-Modified-Since header field makes a GET or HEAD request
method conditional on the selected representation’s modification date
being more recent than the date provided in the field-value.
Transfer of the selected representation’s data is avoided if that
data has not changed.
ABNF
If-Unmodified-Since = HTTP-date
Example Values
Sat, 29 Oct 1994 19:43:31 GMT
Examples
use std::time::{SystemTime, Duration};
use actix_web::HttpResponse;
use actix_web::http::header::IfModifiedSince;
let mut builder = HttpResponse::Ok();
let modified = SystemTime::now() - Duration::from_secs(60 * 60 * 24);
builder.insert_header(
IfModifiedSince(modified.into())
);Tuple Fields
0: HttpDateTrait Implementations
sourceimpl Clone for IfModifiedSince
impl Clone for IfModifiedSince
sourcefn clone(&self) -> IfModifiedSince
fn clone(&self) -> IfModifiedSince
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for IfModifiedSince
impl Debug for IfModifiedSince
sourceimpl Deref for IfModifiedSince
impl Deref for IfModifiedSince
sourceimpl DerefMut for IfModifiedSince
impl DerefMut for IfModifiedSince
sourceimpl Display for IfModifiedSince
impl Display for IfModifiedSince
sourceimpl Header for IfModifiedSince
impl Header for IfModifiedSince
sourcefn name() -> HeaderName
fn name() -> HeaderName
Returns the name of the header field.
sourcefn parse<M: HttpMessage>(msg: &M) -> Result<Self, ParseError>
fn parse<M: HttpMessage>(msg: &M) -> Result<Self, ParseError>
Parse the header from a HTTP message.
sourceimpl PartialEq<IfModifiedSince> for IfModifiedSince
impl PartialEq<IfModifiedSince> for IfModifiedSince
sourcefn eq(&self, other: &IfModifiedSince) -> bool
fn eq(&self, other: &IfModifiedSince) -> bool
sourceimpl TryIntoHeaderValue for IfModifiedSince
impl TryIntoHeaderValue for IfModifiedSince
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
The type returned in the event of a conversion error.
sourcefn try_into_value(self) -> Result<HeaderValue, Self::Error>
fn try_into_value(self) -> Result<HeaderValue, Self::Error>
Try to convert value to a HeaderValue.
impl Eq for IfModifiedSince
impl StructuralEq for IfModifiedSince
impl StructuralPartialEq for IfModifiedSince