pub struct LastModified(pub HttpDate);Expand description
Last-Modified header, defined
in RFC 7232 2.2
The Last-Modified header field in a response provides a timestamp
indicating the date and time at which the origin server believes the
selected representation was last modified, as determined at the
conclusion of handling the request.
ABNF
Expires = HTTP-date
Example Values
Sat, 29 Oct 1994 19:43:31 GMT
Examples
use std::time::{SystemTime, Duration};
use actix_web::HttpResponse;
use actix_web::http::header::LastModified;
let mut builder = HttpResponse::Ok();
let modified = SystemTime::now() - Duration::from_secs(60 * 60 * 24);
builder.insert_header(
LastModified(modified.into())
);Tuple Fields
0: HttpDateTrait Implementations
sourceimpl Clone for LastModified
impl Clone for LastModified
sourcefn clone(&self) -> LastModified
fn clone(&self) -> LastModified
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for LastModified
impl Debug for LastModified
sourceimpl Deref for LastModified
impl Deref for LastModified
sourceimpl DerefMut for LastModified
impl DerefMut for LastModified
sourceimpl Display for LastModified
impl Display for LastModified
sourceimpl Header for LastModified
impl Header for LastModified
sourcefn name() -> HeaderName
fn name() -> HeaderName
Returns the name of the header field.
sourcefn parse<M: HttpMessage>(msg: &M) -> Result<Self, ParseError>
fn parse<M: HttpMessage>(msg: &M) -> Result<Self, ParseError>
Parse the header from a HTTP message.
sourceimpl PartialEq<LastModified> for LastModified
impl PartialEq<LastModified> for LastModified
sourcefn eq(&self, other: &LastModified) -> bool
fn eq(&self, other: &LastModified) -> bool
sourceimpl TryIntoHeaderValue for LastModified
impl TryIntoHeaderValue for LastModified
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
The type returned in the event of a conversion error.
sourcefn try_into_value(self) -> Result<HeaderValue, Self::Error>
fn try_into_value(self) -> Result<HeaderValue, Self::Error>
Try to convert value to a HeaderValue.
impl Eq for LastModified
impl StructuralEq for LastModified
impl StructuralPartialEq for LastModified