pub struct QualityItem<T> {
pub item: T,
pub quality: Quality,
}Expand description
Represents an item with a quality value as defined in RFC 7231 5.3.1.
Parsing and Formatting
This wrapper be used to parse header value items that have a q-factor annotation as well as serialize items with a their q-factor.
Ordering
Since this context of use for this type is header value items, ordering is defined for
QualityItems but only considers the item’s quality. Order of appearance should be used as
the secondary sorting parameter; i.e., a stable sort over the quality values will produce a
correctly sorted sequence.
Examples
let q_item: QualityItem<String> = "hello;q=0.3".parse().unwrap();
assert_eq!(&q_item.item, "hello");
assert_eq!(q_item.quality, q(0.3));
// note that format is normalized compared to parsed item
assert_eq!(q_item.to_string(), "hello; q=0.3");
// item with q=0.3 is greater than item with q=0.1
let q_item_fallback: QualityItem<String> = "abc;q=0.1".parse().unwrap();
assert!(q_item > q_item_fallback);Fields
item: TThe wrapped contents of the field.
quality: QualityThe quality (client or server preference) for the value.
Implementations
sourceimpl<T> QualityItem<T>
impl<T> QualityItem<T>
sourcepub fn new(item: T, quality: Quality) -> QualityItem<T>
pub fn new(item: T, quality: Quality) -> QualityItem<T>
Constructs a new QualityItem from an item and a quality value.
The item can be of any type. The quality should be a value in the range [0, 1].
sourcepub fn max(item: T) -> QualityItem<T>
pub fn max(item: T) -> QualityItem<T>
Constructs a new QualityItem from an item, using the maximum q-value.
sourcepub fn min(item: T) -> QualityItem<T>
pub fn min(item: T) -> QualityItem<T>
Constructs a new QualityItem from an item, using the minimum, non-zero q-value.
sourcepub fn zero(item: T) -> QualityItem<T>
pub fn zero(item: T) -> QualityItem<T>
Constructs a new QualityItem from an item, using zero q-value of zero.